==> lxqt-config_0.16.1.orig.tar.xz: lxqt-config-0.16.1/lxqt-config-file-associations/translations/lxqt-config-file-associations_gl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl">
<context>
    <name>ApplicationChooser</name>
    <message>
        <location filename="../applicationchooser.ui" line="14"/>
        <source>ApplicationChooser</source>
        <translation>Selector de aplicacións</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="46"/>
        <source>Pick an application for:</source>
        <translation>Escolla unha aplicación para:</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="110"/>
        <source>1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="115"/>
        <source>Applications that handle JPEG</source>
        <translation>Aplicacións para manexar JPEG</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="124"/>
        <location filename="../applicationchooser.ui" line="129"/>
        <location filename="../applicationchooser.ui" line="139"/>
        <location filename="../applicationchooser.ui" line="144"/>
        <source>New Subitem</source>
        <translation>Novo subelemento</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="135"/>
        <location filename="../applicationchooser.cpp" line="191"/>
        <location filename="../applicationchooser.cpp" line="217"/>
        <source>Other applications</source>
        <translation>Outras aplicacións</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="147"/>
        <source>Web browsers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="152"/>
        <source>Email clients</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="157"/>
        <source>File managers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="193"/>
        <location filename="../applicationchooser.cpp" line="219"/>
        <source>Other applications that handle %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="194"/>
        <location filename="../applicationchooser.cpp" line="220"/>
        <source>Applications that handle %1</source>
        <translation>Aplicacións para manexar %1</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="305"/>
        <source>No applications found</source>
        <translation>Non se atoparon aplicacións</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="310"/>
        <source>No more applications found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MimetypeViewer</name>
    <message>
        <location filename="../mimetypeviewer.cpp" line="271"/>
        <location filename="../mimetypeviewer.cpp" line="290"/>
        <location filename="../mimetypeviewer.cpp" line="309"/>
        <source>Change...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="275"/>
        <location filename="../mimetypeviewer.cpp" line="294"/>
        <location filename="../mimetypeviewer.cpp" line="313"/>
        <location filename="../mimetypeviewer.cpp" line="327"/>
        <location filename="../mimetypeviewer.cpp" line="388"/>
        <source>None</source>
        <translation>Ningún</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="276"/>
        <location filename="../mimetypeviewer.cpp" line="295"/>
        <location filename="../mimetypeviewer.cpp" line="314"/>
        <source>Choose...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="384"/>
        <source>&amp;Change...</source>
        <translation>&amp;Cambiar...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="389"/>
        <source>&amp;Choose...</source>
        <translation>&amp;Escoller...</translation>
    </message>
</context>
<context>
    <name>mimetypeviewer</name>
    <message>
        <location filename="../mimetypeviewer.ui" line="20"/>
        <source>File Associations</source>
        <translation>Asociacións de ficheiros</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="30"/>
        <source>Associations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="206"/>
        <source>Default application</source>
        <translation>Aplicación predeterminada</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="271"/>
        <source>&amp;Choose...</source>
        <translation>&amp;Escoller...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="305"/>
        <source>Default Applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="347"/>
        <source>Web Browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="412"/>
        <location filename="../mimetypeviewer.ui" line="487"/>
        <location filename="../mimetypeviewer.ui" line="562"/>
        <source>Choose...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="422"/>
        <source>Email Client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="497"/>
        <source>File Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="255"/>
        <location filename="../mimetypeviewer.ui" line="396"/>
        <location filename="../mimetypeviewer.ui" line="471"/>
        <location filename="../mimetypeviewer.ui" line="546"/>
        <source>None</source>
        <translation>Ningunha</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="187"/>
        <source>Patterns</source>
        <translation>Modelos</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="193"/>
        <source>*.txt *.xml</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="146"/>
        <source>MIME type</source>
        <translation>Tipo MIME</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="164"/>
        <location filename="../mimetypeviewer.ui" line="248"/>
        <location filename="../mimetypeviewer.ui" line="389"/>
        <location filename="../mimetypeviewer.ui" line="464"/>
        <location filename="../mimetypeviewer.ui" line="539"/>
        <source>Icon</source>
        <translation>Icona</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="171"/>
        <source>Description</source>
        <translation>Descrición</translation>
    </message>
</context>
</TS>

==> lxqt-config_1.2.0.orig.tar.xz: lxqt-config-1.2.0/lxqt-config-file-associations/translations/lxqt-config-file-associations_gl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl">
<context>
    <name>ApplicationChooser</name>
    <message>
        <location filename="../applicationchooser.ui" line="14"/>
        <source>ApplicationChooser</source>
        <translation>Selector de aplicacións</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="46"/>
        <source>Pick an application for:</source>
        <translation>Escolla unha aplicación para:</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="110"/>
        <source>1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="115"/>
        <source>Applications that handle JPEG</source>
        <translation>Aplicacións para manexar JPEG</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="124"/>
        <location filename="../applicationchooser.ui" line="129"/>
        <location filename="../applicationchooser.ui" line="139"/>
        <location filename="../applicationchooser.ui" line="144"/>
        <source>New Subitem</source>
        <translation>Novo subelemento</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="135"/>
        <location filename="../applicationchooser.cpp" line="191"/>
        <location filename="../applicationchooser.cpp" line="217"/>
        <source>Other applications</source>
        <translation>Outras aplicacións</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="147"/>
        <source>Web browsers</source>
        <translation>Navegadores web</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="152"/>
        <source>Email clients</source>
        <translation>Clientes de correo electrónico</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="157"/>
        <source>File managers</source>
        <translation>Xestores de ficheiros</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="193"/>
        <location filename="../applicationchooser.cpp" line="219"/>
        <source>Other applications that handle %1</source>
        <translation>Outras aplicacións para manexar %1</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="194"/>
        <location filename="../applicationchooser.cpp" line="220"/>
        <source>Applications that handle %1</source>
        <translation>Aplicacións para manexar %1</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="305"/>
        <source>No applications found</source>
        <translation>Non se atoparon aplicacións</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="310"/>
        <source>No more applications found</source>
        <translation>Non se atoparon máis aplicacións</translation>
    </message>
</context>
<context>
    <name>MimetypeViewer</name>
    <message>
        <location filename="../mimetypeviewer.cpp" line="271"/>
        <location filename="../mimetypeviewer.cpp" line="290"/>
        <location filename="../mimetypeviewer.cpp" line="309"/>
        <source>Change...</source>
        <translation>Cambiar...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="275"/>
        <location filename="../mimetypeviewer.cpp" line="294"/>
        <location filename="../mimetypeviewer.cpp" line="313"/>
        <location filename="../mimetypeviewer.cpp" line="327"/>
        <location filename="../mimetypeviewer.cpp" line="388"/>
        <source>None</source>
        <translation>Ningún</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="276"/>
        <location filename="../mimetypeviewer.cpp" line="295"/>
        <location filename="../mimetypeviewer.cpp" line="314"/>
        <source>Choose...</source>
        <translation>Escoller...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="384"/>
        <source>&amp;Change...</source>
        <translation>&amp;Cambiar...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="389"/>
        <source>&amp;Choose...</source>
        <translation>&amp;Escoller...</translation>
    </message>
</context>
<context>
    <name>mimetypeviewer</name>
    <message>
        <location filename="../mimetypeviewer.ui" line="20"/>
        <source>File Associations</source>
        <translation>Asociacións de ficheiros</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="30"/>
        <source>Associations</source>
        <translation>Asociacións</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="206"/>
        <source>Default application</source>
        <translation>Aplicación predeterminada</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="271"/>
        <source>&amp;Choose...</source>
        <translation>&amp;Escoller...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="305"/>
        <source>Default Applications</source>
        <translation>Aplicacións predeterminadas</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="347"/>
        <source>Web Browser</source>
        <translation>Navegador web</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="412"/>
        <location filename="../mimetypeviewer.ui" line="487"/>
        <location filename="../mimetypeviewer.ui" line="562"/>
        <source>Choose...</source>
        <translation>Escoller...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="422"/>
        <source>Email Client</source>
        <translation>Cliente de correo electrónico</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="497"/>
        <source>File Manager</source>
        <translation>Xestor de ficheiros</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="255"/>
        <location filename="../mimetypeviewer.ui" line="396"/>
        <location filename="../mimetypeviewer.ui" line="471"/>
        <location filename="../mimetypeviewer.ui" line="546"/>
        <source>None</source>
        <translation>Ningunha</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="187"/>
        <source>Patterns</source>
        <translation>Modelos</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="193"/>
        <source>*.txt *.xml</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="146"/>
        <source>MIME type</source>
        <translation>Tipo MIME</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="164"/>
        <location filename="../mimetypeviewer.ui" line="248"/>
        <location filename="../mimetypeviewer.ui" line="389"/>
        <location filename="../mimetypeviewer.ui" line="464"/>
        <location filename="../mimetypeviewer.ui" line="539"/>
        <source>Icon</source>
        <translation>Icona</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="171"/>
        <source>Description</source>
        <translation>Descrición</translation>
    </message>
</context>
</TS>
